<?php
/**
 * Clipsan API facade class
 * @author Clipsan
 */
class clipsan_api_facade {

    protected $base;
    protected $key;

    public function __construct($key = '', $base = '')
    {
        if (!$key)
        {
            $this->key = get_option ( 'clipsan_securekey' );
        }
        else
        {
            $this->key = $key;
        }
        if (!$base)
        {
            $this->base = $_SERVER['HTTP_HOST'] != 'localhost' ? 'https://clipsan.com/' : 'http://localhost/clipsan/subdomains/public/';
        }
        else
        {
            $this->base = $base;
        }
    }

    static public function factory()
    {
        return new clipsan_api_facade();
    }

    /**
     * @param string $email
     * @param string $firstname
     * @param string $lastname
     * @param string $phone
     */
    public function addLead($list, $tag, $funnel, $email, $firstname, $lastname, $phone = '')
    {
        global $wpdb;

        $url = $this->base.'api/lead/add/';
        $url .= '?key='.$this->key;
        $url .= '&email='.$email;
        $url .= '&firstname='.urlencode(trim($firstname));
        $url .= '&surname='.urlencode(trim($lastname));
        if ($phone)
        {
            $url .= '&phone='.urlencode(trim($phone));
        }

        if ($list)
        {
            if (strpos($list, ';') !== '')
            {
                $lists = explode(';', $list);
                $url .= '&list[]=' . implode('&list[]=', $lists);
            } else
            {
                $url .= '&list=' . urlencode($list);
            }
        }

        if ($tag)
        {
            $url .= '&tag=' . urlencode($tag);
        }

        if ($funnel)
        {
            if (strpos($funnel, ';') !== '')
            {
                $funnels = explode(';', $funnel);
                $url .= '&funnel[]=' . implode('&funnel[]=', $funnels);
            } else
            {
                $url .= '&funnel=' . urlencode($list);
            }
        }

        $currentUri = isset($_SERVER["HTTP_REFERER"]) ? $_SERVER["HTTP_REFERER"] : (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http") . "://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
        $url .= '&ip='.urlencode($_SERVER ['REMOTE_ADDR']);
        $url .= '&referer='.urlencode($currentUri);

        // perform API call
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        $json = curl_exec($ch);
        $status_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        $result = json_decode($json);

        // save to log
        $wpdb->insert(clipsan_woo_handler::getInstance()->getLogTableName(), array(
            'request' => $url,
            'response' => $json,
            'ip' => $_SERVER ['REMOTE_ADDR'],
            'added' => date('Y-m-d H:i:s')
        ));

        // handle error
        if ($result->result != 'ok')
        {
            wp_mail(get_option('admin_email'), 'Clipsan Lead Not Created', 'Clipsan Lead ' . $email . ' could not been created. Check response ID ' . $wpdb->insert_id);
        }
        else
        {
            return $result->id;
        }
    }

    public function bought($lead, $order, $product, $quantity, $price = 0)
    {
        global $wpdb;

        // create call
        $url = $this->base.'api/bought/add/';
        $url .= '?key='.$this->key;
        $url .= '&id='.$lead;
        $url .= '&order_id='.intval($order);
        $url .= '&product_name='.urlencode($product);
        $url .= '&product_quantity='.intval($quantity);
        $url .= '&total_price='.urlencode($price);

        // perform API call
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        $json = curl_exec($ch);
        $status_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        $result = json_decode($json);

        // save to log
        $wpdb->insert(clipsan_woo_handler::getInstance()->getLogTableName(), array(
            'request' => $url,
            'response' => $json,
            'ip' => $_SERVER ['REMOTE_ADDR'],
            'added' => date('Y-m-d H:i:s')
        ));
    }
}

