<?php
/**
 * Clipsan WooCommerce plugin class
 * @author Clipsan
 */
class clipsan_woo_handler {
	
	/**
	 *
	 * @var string
	 */
	protected static $instance;
	
	/**
	 * Default constructor
	 */
	protected function __construct($file) {
		register_activation_hook ( $file, array (
				$this,
				'activation' 
		) );
		register_deactivation_hook ( $file, array (
				$this,
				'deactivation' 
		) );
		
		add_action ( 'admin_menu', array (
				$this,
				'adminMenu' 
		) );
	}
	
	/**
	 * Get instance
	 *
	 * @return clipsan_woo_handler
	 */
	public static function getInstance($file = '') {
		if (! isset ( self::$instance )) {
			self::$instance = new clipsan_woo_handler ($file);
		}
		
		return self::$instance;
	}
	
	function activation() {
		add_option ( 'clipsan_securekey' );
		
		$table_name = $this->getLogTableName ();
		
		$charset_collate = '';
		
		if (! empty ( $wpdb->charset ))
			$charset_collate = "DEFAULT CHARACTER SET $wpdb->charset";
		if (! empty ( $wpdb->collate ))
			$charset_collate .= " COLLATE $wpdb->collate";
		
		$sql = "CREATE TABLE $table_name (
			id int(11) NOT NULL AUTO_INCREMENT,
			request TEXT DEFAULT NULL,
			response TEXT DEFAULT NULL,
			ip VARCHAR(20) DEFAULT NULL,
			user_id int(11) DEFAULT NULL,
			added datetime NOT NULL,
			PRIMARY KEY (`id`)
		) ENGINE=MyISAM $charset_collate";
		
		require_once (ABSPATH . 'wp-admin/includes/upgrade.php');
		dbDelta ( $sql );
	}
	
	function deactivation() {
		global $wpdb;
		
		delete_option ( 'clipsan_securekey' );
		delete_option ( 'clipsan_woo_list' );
		delete_option ( 'clipsan_woo_tag' );
		delete_option ( 'clipsan_woo_tag' );

		$sql = "DROP TABLE IF EXISTS " . $this->getLogTableName () . ";";
		$wpdb->query ( $sql );
	}
	
	function adminMenu() {
		add_options_page ( __('Clipsan WooCom.', 'clipsan'), __('Clipsan WooCom.', 'clipsan'), 'manage_options', 'clipsan-woo', array (
				$this,
				'admin' 
		) );
	}
	
	function admin() {
		if (isset ( $_POST ['clipsan_submit'] )) {
			update_option ( 'clipsan_securekey', stripslashes ( $_POST ['clipsan_securekey'] ) );
			update_option ( 'clipsan_woo_list', stripslashes ( $_POST ['clipsan_list'] ) );
			update_option ( 'clipsan_woo_tag', stripslashes ( $_POST ['clipsan_tag'] ) );
			update_option ( 'clipsan_woo_funnel', stripslashes ( $_POST ['clipsan_funnel'] ) );
            update_option('clipsan_newsletter_check', (key_exists('clipsan_newsletter_check', $_POST) && $_POST ['clipsan_newsletter_check']) ? true : false);
            if (key_exists('clipsan_newsletter_label', $_POST))
            {
                update_option ( 'clipsan_newsletter_label', stripslashes ($_POST ['clipsan_newsletter_label'] ) );
            }
		}
		$clipsan_securekey = get_option ( 'clipsan_securekey' );
		$clipsan_list = get_option ( 'clipsan_woo_list' );
		$clipsan_tag = get_option ( 'clipsan_woo_tag' );
		$clipsan_funnel = get_option ( 'clipsan_woo_funnel' );
		$clipsan_newsletter_check = get_option ( 'clipsan_newsletter_check' );
        $clipsan_newsletter_label = get_option ( 'clipsan_newsletter_label' ) ?: 'Přihlásit k odběru zpráv';

		?>
<div class="wrap">
	<h2>Nastavení propojení WooCommerce a Clipsan</h2>
	<form name="form_mt" method="post" action="">
		<table class="form-table">
			<tr valign="top">
				<th scope="row"><label for="clipsan_securekey"><?php _e('Chráněný klíč', 'clipsan') ?></label></th>
				<td><input name="clipsan_securekey" type="text"
					value="<?php echo $clipsan_securekey; ?>" id="clipsan_securekey"
					class="regular-text" placeholder="<?php _e('Zadejte chráněný klíč', 'clipsan') ?>"
					required="required" /><br /><span class="description"><?php _e('Chráněný klíč získáte <a href="https://clipsan.com/cs/clipsan/securekey">zde</a>.', 'clipsan') ?></span></td>
            </tr><tr valign="top">
                <th scope="row"><label for="clipsan_list"><?php _e('Zařadit do skupiny', 'clipsan') ?></label></th>
                <td><input name="clipsan_list" type="text"
                           value="<?php echo $clipsan_list; ?>" id="clipsan_list"
                           class="regular-text" placeholder="<?php _e('Zadejte kód skupiny', 'clipsan') ?>" /><br /><span class="description"><?php _e('Kód pro skupinu získáte <a href="https://clipsan.com/cs/marketing/list">zde</a>. Více skupin oddělte středníkem.', 'clipsan') ?></span></td>
            </tr><tr valign="top">
                <th scope="row"><label for="clipsan_funnel"><?php _e('Automat', 'clipsan') ?></label></th>
                <td><input name="clipsan_funnel" type="text"
                           value="<?php echo $clipsan_funnel; ?>" id="clipsan_funnel"
                           class="regular-text" placeholder="<?php _e('Zařadit kontakty do automatu', 'clipsan') ?>" />
                    <br /><span class="description"><?php _e('ID automatu získáte <a href="https://clipsan.com/cs/marketing/funnel">zde</a>. Více automatů oddělte středníkem.', 'clipsan') ?></span></td>
            </tr><tr valign="top">
                <th scope="row"><label for="clipsan_tag"><?php _e('Štítek', 'clipsan') ?></label></th>
                <td><input name="clipsan_tag" type="text"
                           value="<?php echo $clipsan_tag; ?>" id="clipsan_tag"
                           class="regular-text" placeholder="<?php _e('Označte kontakty štítkem', 'clipsan') ?>" /></td>
            </tr><tr valign="top">
                <th scope="row"><label for="clipsan_newsletter_check"><?php _e('Dobrovolné přihlášení', 'clipsan') ?></label></th>
                <td><input name="clipsan_newsletter_check" type="checkbox"
                           value="1" id="clipsan_newsletter_check"
                           class="regular-checkbox" <?php echo $clipsan_newsletter_check ? 'checked="checked"' : '' ?> /></td>
            </tr><tr valign="top">
                <th scope="row"><label for="clipsan_newsletter_label"><?php _e('Text u přihlášení', 'clipsan') ?></label></th>
                <td><input name="clipsan_newsletter_label" type="text"
                           value="<?php echo $clipsan_newsletter_label ; ?>" id="clipsan_newsletter_label"
                           class="regular-text" placeholder="<?php _e('Přihlásit k odběru zpráv', 'clipsan') ?>" /></td>
            </tr>
		</table>
		<p class="submit">
			<input type="submit" name="clipsan_submit" id="clipsan_submit"
				class="button-primary" value="<?php _e('Uložit změny', 'clipsan') ?>" />
		</p>
	</form>
</div>
<?php
	}
	
	public function getLogTableName() {
		global $wpdb;
		return $wpdb->prefix . "clipsan_woo_log";
	}

	public function plugin_links($links, $file) {
        if ( 'clipsan-woo/clipsan-woo.php' !== $file ) {
            return $links;
        }

        $row_meta = array(
            'settings'    => '<a href="'.admin_url('options-general.php?page=clipsan-woo').'">Nastavení</a>'
        );

        return array_merge( $links, $row_meta );
    }

    /**
     * Displays notice when plugin is installed but not yet configured / connected to Mailchimp.
     */
    public function initial_notice() {
        if (!get_option ( 'clipsan_securekey' )) {
            $class = 'notice notice-warning is-dismissible';
            $url = admin_url( 'admin.php?page=clipsan-woo');
            $message = __('<strong>Propojení WooCommerce a Clipsanu</strong> ještě není nastaveno. <a href="'.$url.'">Dokončete nastavení</a>', 'clipsan');
            printf( '<div class="%1$s"><p>%2$s</p></div>', $class, $message );
        }
    }
}

