<?php
/**
 * Clipsan WooCommerce newsletter class
 * Based upon MailChimp_Newsletter
 * @author Clipsan
 */
class clipsan_woo_newsletter {

    public static $meta = 'clipsan_woocommerce_is_subscribed';
    public static $input = 'clipsan_woocommerce_newsletter';

    /**
     * @param WC_Checkout $checkout
     */
    public function applyNewsletterField($checkout)
    {
        $default_checked = get_option('clipsan_newsletter_checkbox', 'check');
        $label = get_option('clipsan_newsletter_label') ?: 'Přihlásit k odběru zpráv';

        if (is_user_logged_in()) {
            $status = get_user_meta(get_current_user_id(), 'clipsan_woocommerce_is_subscribed', true);
            /// if the user is logged in - and is already subscribed - just ignore this checkbox.
            if ((bool) $status) {
                return;
            }
            if ($status === '' || $status === null) {
                $status = $default_checked;
            }
        }

        // echo out the subscription checkbox.
        $checkbox = '<p class="form-row form-row-wide clipsan-newsletter">';
        $checkbox .= '<label class="woocommerce-form__label woocommerce-form__label-for-checkbox checkbox">';
        $checkbox .= '<input id="clipsan_woocommerce_newsletter" class="woocommerce-form__input woocommerce-form__input-checkbox input-checkbox" type="checkbox" name="'.self::$input.'" value="1"'.($status ? ' checked="checked"' : '').'> ';
        $checkbox .= '<span>' . $label . '</span></label></p>';
        $checkbox .= '<div class="clear"></div>';

        echo apply_filters( 'clipsan_woocommerce_newsletter_field', $checkbox, $status, $label);
    }

    /**
     * @param $order_id
     * @param $posted
     */
    public function processNewsletterField($order_id, $posted)
    {
        $this->handleStatus($order_id);
    }

    /**
     * @param WC_Order $order
     */
    public function processPayPalNewsletterField($order)
    {
        $this->handleStatus($order->get_id());
    }

    /**
     * @param $sanitized_user_login
     * @param $user_email
     * @param $reg_errors
     */
    public function processRegistrationForm($sanitized_user_login, $user_email, $reg_errors)
    {
        if (defined('WOOCOMMERCE_CHECKOUT')) {
            return; // Ship checkout
        }

        $this->handleStatus();
    }

    /**
     * @param null $order_id
     * @return bool|int
     */
    protected function handleStatus($order_id = null)
    {
        $logged_in = is_user_logged_in();

        // if the post key is available we use it - otherwise we null it out.
        $status = isset($_POST[self::$input]) ? (int) $_POST[self::$input] : null;

        // if the status is null, we don't do anything
        if ($status === null) {
            return false;
        }

        // if we passed in an order id, we update it here.
        if ($order_id) {
            update_post_meta($order_id, self::$meta, $status);
        }

        // if the user is logged in, we will update the status correctly.
        if ($logged_in) {
            update_user_meta(get_current_user_id(), self::$meta, $status);
            return $status;
        }

        return false;
    }
}
