<?php
/**
 * Clipsan WooCommerce service class
 * @author Clipsan
 */
class clipsan_woo_service {

    public function init()
    {
        add_action('user_register', array($this, 'handleUserRegistration'), 33, 1);
        add_action('woocommerce_order_status_changed', array($this, 'handleOrderStatusChanged'), 33, 3);
    }

    /**
     * @param int $user_id
     */
    public function handleUserRegistration($user_id)
    {
        if (!$this->isConfigured())
        {
            $this->log('debug', "handleUserRegistration: clipsan not configured");
            return;
        }

        $user = new WP_User($user_id);
        if ($user->ID > 0)
        {
            if (get_option('clipsan_newsletter_check'))
            {
                $subscribed = (bool) isset($_POST[clipsan_woo_newsletter::$input]) && $_POST[clipsan_woo_newsletter::$input] ? true : false;
                update_user_meta($user->ID, clipsan_woo_newsletter::$meta, $subscribed);
                if ($subscribed)
                {
                    $this->addLead($user->user_email, $user->first_name, $user->last_name);
                }
            }
            else
            {
                $this->addLead($user->user_email, $user->first_name, $user->last_name);
            }
        }
    }

    /**
     * @param int $order_id
     * @param string $old_status
     * @param string $new_status
     */
    public function handleOrderStatusChanged($order_id, $old_status, $new_status)
    {
        if (!$this->isConfigured())
        {
            $this->log('debug', "handleOrderStatusChanged: clipsan not configured");
            return;
        }

        if ("pending" == $old_status && ("processing" == $new_status || "completed" == $new_status || "on-hold" == $new_status || "na-dobirku" == $new_status)) {
            $this->handleNewOrder($order_id);
        }
        elseif ("on-hold" == $old_status && ("processing" == $new_status || "completed" == $new_status || "partial-shipped" == $new_status)) {
            $this->handleNewOrder($order_id);
        }
        else {
            $this->log('debug', "order $order_id change $old_status => $new_status");
        }
    }

    /**
     * @param int $post_id
     */
    protected function handleNewOrder($order_id)
    {
        $order = wc_get_order($order_id);

        if (empty($order)) {
            $this->error('sync', 'get woo post was not found for order '.$order_id);
            return;
        }

        if (!method_exists($order, 'get_billing_email')) {
            $this->log('sync', "Post ID {$order_id} was an order refund. Skipping this.");
            return;
        }

        $subscribed = get_post_meta($order_id, clipsan_woo_newsletter::$meta, true);
        if (get_option('clipsan_newsletter_check') && !$subscribed) {
            $this->log('sync', "Order ID {$order_id} customer does not want any emails. Skipping this.");
            return;
        }

        $lead_id = $this->addLead($order->get_billing_email(), $order->get_billing_first_name(), $order->get_billing_last_name(), $order->get_billing_phone());
        $order_items = $order->get_items();
        foreach( $order_items as $product ) {
            /* @var $product WC_Order_Item_Product */
            clipsan_api_facade::factory()->bought($lead_id, $product->get_order_id(), $product->get_name(), $product->get_quantity(), $product->get_total());
        }
    }

    protected function addLead($email, $firstname, $lastname, $phone = null)
    {
        $clipsan_list = get_option ( 'clipsan_woo_list' );
        $clipsan_tag = get_option ( 'clipsan_woo_tag' );
        $clipsan_funnel = get_option ( 'clipsan_woo_funnel' );
        return clipsan_api_facade::factory()->addLead($clipsan_list, $clipsan_tag, $clipsan_funnel, $email, $firstname, $lastname, $phone);
    }

    /**
     * @return bool
     */
    protected function isConfigured() {
        return (bool) get_option ( 'clipsan_securekey' );
    }

    /**
     * @param string $action
     * @param string $message
     * @param array $data
     */
    protected function log($action, $message, $data = array()) {
        if (function_exists('wc_get_logger')) {
            if (is_array($data) && !empty($data)) $message .= " :: ".wc_print_r($data, true);
            wc_get_logger()->notice("{$action} :: {$message}", array('source' => 'clipsan_woocommerce'));
        }
        // local debug
        if ($_SERVER['HTTP_HOST'] == 'localhost')
        {
            $fp = fopen(__DIR__ . '/log.txt', 'a');
            fwrite($fp, "{$action} :: {$message}\n");
            fclose($fp);
        }
    }

    /**
     * @param string $action
     * @param string $message
     * @param array $data
     */
    protected function error($action, $message, $data = array()) {
        if (function_exists('wc_get_logger')) {
            if (is_array($data) && !empty($data)) $message .= " :: ".wc_print_r($data, true);
            wc_get_logger()->error("{$action} :: {$message}", array('source' => 'clipsan_woocommerce'));
        }
        // local debug
        if (strpos(_CLIPSAN_BASE, 'localhost'))
        {
            $fp = fopen(__DIR__ . '/error.txt', 'a');
            fwrite($fp, "{$action} :: {$message}\n");
            fclose($fp);
        }
    }
}

